| Title: | Get Free Proxy IP and Port |
|---|---|
| Description: | Allows get address and port of the free proxy server, from one of two services <http://gimmeproxy.com/> or <https://getproxylist.com/>. And it's easy to redirect your Internet connection through a proxy server. |
| Authors: | Alexey Seleznev <[email protected]> |
| Maintainer: | Alexey Seleznev <[email protected]> |
| License: | GPL-2 |
| Version: | 1.13 |
| Built: | 2026-06-01 09:57:43 UTC |
| Source: | https://github.com/selesnow/getproxy |
Allows get address and port of the free proxy server, from one of two services <http://gimmeproxy.com/> or <https://getproxylist.com/>. And it's easy to redirect your Internet connection through a proxy server.
The DESCRIPTION file:
| Package: | getProxy |
| Type: | Package |
| Title: | Get Free Proxy IP and Port |
| Version: | 1.13 |
| Date: | 2022-01-05 |
| Author: | Alexey Seleznev <[email protected]> |
| Maintainer: | Alexey Seleznev <[email protected]> |
| Description: | Allows get address and port of the free proxy server, from one of two services <http://gimmeproxy.com/> or <https://getproxylist.com/>. And it's easy to redirect your Internet connection through a proxy server. |
| Depends: | R (>= 3.5.0) |
| BugReports: | https://github.com/selesnow/getProxy/issues |
| Imports: | httr, cli |
| URL: | https://selesnow.github.io/getProxy/ |
| License: | GPL-2 |
| Config/pak/sysreqs: | libssl-dev |
| Repository: | https://selesnow.r-universe.dev |
| Date/Publication: | 2022-01-06 06:42:15 UTC |
| RemoteUrl: | https://github.com/selesnow/getproxy |
| RemoteRef: | HEAD |
| RemoteSha: | 7403d3b8380db9c87ef6ffe880a57cee824c18e5 |
Index of help topics:
getProxy Get ip and port by free proxy, start ans stop
internet connection over free proxy server.
getProxy-package Get Free Proxy IP and Port
Alexey Seleznev <[email protected]>
Maintainer: Alexey Seleznev <[email protected]>
## Not run: library(getProxy) #For get ans start proxy settings prox_ip_and_port <- getProxy(port = "3128", country = "RU", action = "start") # This put you code for get data # from blocked source #For stop proxy getProxy(action = "stop") ## End(Not run)## Not run: library(getProxy) #For get ans start proxy settings prox_ip_and_port <- getProxy(port = "3128", country = "RU", action = "start") # This put you code for get data # from blocked source #For stop proxy getProxy(action = "stop") ## End(Not run)
Get IP and Port from one of service gimmeproxy.com or getproxylist.com, and return him in your R environment. Also this function can start and stop proxy seting in R.
getProxy( country = NULL, notCountry = NULL, supportsHttps = TRUE, port = NULL, type = "http", action = "start")getProxy( country = NULL, notCountry = NULL, supportsHttps = TRUE, port = NULL, type = "http", action = "start")
country |
Character, country code in ISO 3166-1 alpha-2, for more ditail go link |
notCountry |
Character, country code in ISO 3166-1 alpha-2, for more ditail go - link |
supportsHttps |
Logical, TRUE of FALSE supports HTTPS requests |
port |
Character, Port available on |
type |
Character, Proxy protocol, one of "http", "socks4", "socks5" |
action |
Character, wath do with proxy, one of "get" for get IP and PORT, "start" for get IP and PORT and start proxy settings, "stop" for stop proxy settings |
You can use getProxy when you needed get data from blocked on you country internet source.
Alexey Seleznev
Package use three services gimmeproxy, proxy-list.download and getproxylist.
## Not run: #For get IP and PORT in R object prox_ip_and_port <- getProxy(port = "3128", country = "RU", action = "get") #For get and start proxy settings prox_ip_and_port <- getProxy(port = "3128", country = "RU", action = "start") #For stop proxy getProxy(action = "stop") ## End(Not run)## Not run: #For get IP and PORT in R object prox_ip_and_port <- getProxy(port = "3128", country = "RU", action = "get") #For get and start proxy settings prox_ip_and_port <- getProxy(port = "3128", country = "RU", action = "start") #For stop proxy getProxy(action = "stop") ## End(Not run)